/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.canvas;

public class FigureElement extends com.mysql.grt.GrtObject {

    protected FigureElement() {
    }

    public FigureElement(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new FigureElementDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new FigureElementDataGlobal((String) obj);
        }
    }

    public int getResizable() {
        return ((FigureElementData) data).getResizable();
    }

    public int setResizable(int resizable) {
        ((FigureElementData) data).setResizable(resizable);

        return getResizable();
    }

    public int getExpanded() {
        return ((FigureElementData) data).getExpanded();
    }

    public int setExpanded(int expanded) {
        ((FigureElementData) data).setExpanded(expanded);

        return getExpanded();
    }

    public double getConstraintMaxHeight() {
        return ((FigureElementData) data).getConstraintMaxHeight();
    }

    public double setConstraintMaxHeight(double constraintMaxHeight) {
        ((FigureElementData) data).setConstraintMaxHeight(constraintMaxHeight);

        return getConstraintMaxHeight();
    }

    public double getConstraintMaxWidth() {
        return ((FigureElementData) data).getConstraintMaxWidth();
    }

    public double setConstraintMaxWidth(double constraintMaxWidth) {
        ((FigureElementData) data).setConstraintMaxWidth(constraintMaxWidth);

        return getConstraintMaxWidth();
    }

    public double getConstraintMinHeight() {
        return ((FigureElementData) data).getConstraintMinHeight();
    }

    public double setConstraintMinHeight(double constraintMinHeight) {
        ((FigureElementData) data).setConstraintMinHeight(constraintMinHeight);

        return getConstraintMinHeight();
    }

    public double getConstraintMinWidth() {
        return ((FigureElementData) data).getConstraintMinWidth();
    }

    public double setConstraintMinWidth(double constraintMinWidth) {
        ((FigureElementData) data).setConstraintMinWidth(constraintMinWidth);

        return getConstraintMinWidth();
    }

    public String getLayout() {
        return ((FigureElementData) data).getLayout();
    }

    public String setLayout(String layout) {
        ((FigureElementData) data).setLayout(layout);

        return getLayout();
    }

    public String getStyle() {
        return ((FigureElementData) data).getStyle();
    }

    public String setStyle(String style) {
        ((FigureElementData) data).setStyle(style);

        return getStyle();
    }

    public com.mysql.grt.GrtHashMap getCaption() {
        return ((FigureElementData) data).getCaption();
    }

    public com.mysql.grt.GrtHashMap setCaption(com.mysql.grt.GrtHashMap caption) {
        ((FigureElementData) data).setCaption(caption);

        return getCaption();
    }

    public com.mysql.grt.canvas.FigureElementList getChildren() {
        return ((FigureElementData) data).getChildren();
    }

    public com.mysql.grt.canvas.FigureElementList setChildren(com.mysql.grt.canvas.FigureElementList children) {
        ((FigureElementData) data).setChildren(children);

        return getChildren();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"resizable\">"
                    + Integer.toString(getResizable()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"expanded\">"
                    + Integer.toString(getExpanded()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"constraintMaxHeight\">"
                    + Double.toString(getConstraintMaxHeight()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"constraintMaxWidth\">"
                    + Double.toString(getConstraintMaxWidth()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"constraintMinHeight\">"
                    + Double.toString(getConstraintMinHeight()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"constraintMinWidth\">"
                    + Double.toString(getConstraintMinWidth()) + "</value>\n");

            if (getLayout() != null) {
                xml.append("<value type=\"string\" key=\"layout\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getLayout()) + "</value>\n");
            }

            if (getStyle() != null) {
                xml.append("<value type=\"string\" key=\"style\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getStyle()) + "</value>\n");
            }

            if (getChildren() != null) {
                getChildren().getGrtXml(xml, " key=\"children\"");
            }

            if (getCaption() != null) {
                getCaption().getGrtXml(xml, " key=\"caption\"");
            }

        return xml;
    }
}
