/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db;

public class ForeignKey extends com.mysql.grt.base.NamedGrtObject {

    protected ForeignKey() {
    }

    public ForeignKey(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new ForeignKeyDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new ForeignKeyDataGlobal((String) obj);
        }
    }

    public int getDeferability() {
        return ((ForeignKeyData) data).getDeferability();
    }

    public int setDeferability(int deferability) {
        ((ForeignKeyData) data).setDeferability(deferability);

        return getDeferability();
    }

    public String getDeleteRule() {
        return ((ForeignKeyData) data).getDeleteRule();
    }

    public String setDeleteRule(String deleteRule) {
        ((ForeignKeyData) data).setDeleteRule(deleteRule);

        return getDeleteRule();
    }

    public String getUpdateRule() {
        return ((ForeignKeyData) data).getUpdateRule();
    }

    public String setUpdateRule(String updateRule) {
        ((ForeignKeyData) data).setUpdateRule(updateRule);

        return getUpdateRule();
    }

    public String getReferedTableSchemaName() {
        return ((ForeignKeyData) data).getReferedTableSchemaName();
    }

    public String setReferedTableSchemaName(String referedTableSchemaName) {
        ((ForeignKeyData) data).setReferedTableSchemaName(referedTableSchemaName);

        return getReferedTableSchemaName();
    }

    public String getReferedTableName() {
        return ((ForeignKeyData) data).getReferedTableName();
    }

    public String setReferedTableName(String referedTableName) {
        ((ForeignKeyData) data).setReferedTableName(referedTableName);

        return getReferedTableName();
    }

    public com.mysql.grt.GrtStringList getReferedColumnNames() {
        return ((ForeignKeyData) data).getReferedColumnNames();
    }

    public com.mysql.grt.GrtStringList setReferedColumnNames(com.mysql.grt.GrtStringList referedColumnNames) {
        ((ForeignKeyData) data).setReferedColumnNames(referedColumnNames);

        return getReferedColumnNames();
    }

    public com.mysql.grt.db.Table getReferedTable() {
        return ((ForeignKeyData) data).getReferedTable();
    }

    public com.mysql.grt.db.Table setReferedTable(com.mysql.grt.db.Table referedTable) {
        ((ForeignKeyData) data).setReferedTable(referedTable);

        return getReferedTable();
    }

    public String getReferedTableById() {
        return ((ForeignKeyData) data).getReferedTableById();
    }

    public void setReferedTableById(String referedTable) {
        ((ForeignKeyData) data).setReferedTableById(referedTable);
    }

    public com.mysql.grt.db.ColumnList getColumns() {
        return ((ForeignKeyData) data).getColumns();
    }

    public com.mysql.grt.db.ColumnList setColumns(com.mysql.grt.db.ColumnList columns) {
        ((ForeignKeyData) data).setColumns(columns);

        return getColumns();
    }

    public com.mysql.grt.db.ColumnList getReferedColumns() {
        return ((ForeignKeyData) data).getReferedColumns();
    }

    public com.mysql.grt.db.ColumnList setReferedColumns(com.mysql.grt.db.ColumnList referedColumns) {
        ((ForeignKeyData) data).setReferedColumns(referedColumns);

        return getReferedColumns();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"deferability\">"
                    + Integer.toString(getDeferability()) + "</value>\n");

            if (getDeleteRule() != null) {
                xml.append("<value type=\"string\" key=\"deleteRule\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDeleteRule()) + "</value>\n");
            }

            if (getUpdateRule() != null) {
                xml.append("<value type=\"string\" key=\"updateRule\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getUpdateRule()) + "</value>\n");
            }

            if (getReferedTableSchemaName() != null) {
                xml.append("<value type=\"string\" key=\"referedTableSchemaName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getReferedTableSchemaName()) + "</value>\n");
            }

            if (getReferedTableName() != null) {
                xml.append("<value type=\"string\" key=\"referedTableName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getReferedTableName()) + "</value>\n");
            }

            if (getReferedColumnNames() != null) {
                getReferedColumnNames().getGrtXml(xml, " key=\"referedColumnNames\"");
            }

            if (getReferedTable() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"referedTable\">"
                        + getReferedTableById() + "</value>\n");
            }

            if (getColumns() != null) {
                getColumns().getGrtRefXml(xml, " key=\"columns\"");
            }

            if (getReferedColumns() != null) {
                getReferedColumns().getGrtRefXml(xml, " key=\"referedColumns\"");
            }

        return xml;
    }
}
