/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.workbench;

public class TableElement extends com.mysql.grt.model.Element {

    protected TableElement() {
    }

    public TableElement(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new TableElementDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new TableElementDataGlobal((String) obj);
        }
    }

    public int getColumnsExpanded() {
        return ((TableElementData) data).getColumnsExpanded();
    }

    public int setColumnsExpanded(int columnsExpanded) {
        ((TableElementData) data).setColumnsExpanded(columnsExpanded);

        return getColumnsExpanded();
    }

    public int getIndicesExpanded() {
        return ((TableElementData) data).getIndicesExpanded();
    }

    public int setIndicesExpanded(int indicesExpanded) {
        ((TableElementData) data).setIndicesExpanded(indicesExpanded);

        return getIndicesExpanded();
    }

    public int getForeignKeysExpanded() {
        return ((TableElementData) data).getForeignKeysExpanded();
    }

    public int setForeignKeysExpanded(int foreignKeysExpanded) {
        ((TableElementData) data).setForeignKeysExpanded(foreignKeysExpanded);

        return getForeignKeysExpanded();
    }

    public int getTriggersExpanded() {
        return ((TableElementData) data).getTriggersExpanded();
    }

    public int setTriggersExpanded(int triggersExpanded) {
        ((TableElementData) data).setTriggersExpanded(triggersExpanded);

        return getTriggersExpanded();
    }

    public String getColor() {
        return ((TableElementData) data).getColor();
    }

    public String setColor(String color) {
        ((TableElementData) data).setColor(color);

        return getColor();
    }

    public com.mysql.grt.db.Table getTable() {
        return ((TableElementData) data).getTable();
    }

    public com.mysql.grt.db.Table setTable(com.mysql.grt.db.Table table) {
        ((TableElementData) data).setTable(table);

        return getTable();
    }

    public String getTableById() {
        return ((TableElementData) data).getTableById();
    }

    public void setTableById(String table) {
        ((TableElementData) data).setTableById(table);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"columnsExpanded\">"
                    + Integer.toString(getColumnsExpanded()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"indicesExpanded\">"
                    + Integer.toString(getIndicesExpanded()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"foreignKeysExpanded\">"
                    + Integer.toString(getForeignKeysExpanded()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"triggersExpanded\">"
                    + Integer.toString(getTriggersExpanded()) + "</value>\n");

            if (getColor() != null) {
                xml.append("<value type=\"string\" key=\"color\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getColor()) + "</value>\n");
            }

            if (getTable() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"table\">"
                        + getTableById() + "</value>\n");
            }

        return xml;
    }
}
